@@ -1,4 +1,4 @@
 from consoles import *
 from abstract_gui import *
-#startIdeConsole()
-startConsole(ideTab)
+startConsole(appRunnerTab)
+
